pub enum Error {
FindPostgres(Error),
FindInitdb(Error),
FindPsql(Error),
CreateDatabaseDir(Error),
WriteTemporaryPw(Error),
RunInitDb(Error),
InitDbFailed(ExitStatus),
LaunchPostgres(Error),
StartupTimeout,
RunPsql(Error),
PsqlFailed(ExitStatus),
InvalidExternalUrl(ExternalUrlError),
}Expand description
A Postgres server error.
Variants
FindPostgres(Error)
FindInitdb(Error)
Failed to find the initdb binary.
FindPsql(Error)
Failed to find the postgres binary.
CreateDatabaseDir(Error)
Could not create the temporary directory.
WriteTemporaryPw(Error)
Could not write the temporary password to a file.
RunInitDb(Error)
Starting initdb failed.
InitDbFailed(ExitStatus)
Running initdb was not successful.
LaunchPostgres(Error)
Postgres could not be launched.
StartupTimeout
Postgres was launched but failed to bring up a TCP-connection accepting socket in time.
RunPsql(Error)
psql could not be launched.
PsqlFailed(ExitStatus)
Running psql returned an error.
InvalidExternalUrl(ExternalUrlError)
Invalid external test URL.